# eric7.Plugins.CheckerPlugins.SyntaxChecker.tomlCheckSyntax

Module implementing the syntax check for TOML.

### Global Attributes

None

### Classes

None

### Functions

__tomlSyntaxCheck | Function to check a TOML source file for syntax errors.
initBatchService | Initialize the batch service and return the entry point.
initService | Initialize the service and return the entry point.
tomlSyntaxBatchCheck | Module function to check syntax for a batch of files.
tomlSyntaxCheck | Function to check a TOML source file for syntax errors.
workerTask | Module function acting as the parallel worker for the syntax check.

## __tomlSyntaxCheck

__tomlSyntaxCheck(file, codestring)

Function to check a TOML source file for syntax errors.

file (str)
  source filename
codestring (str)
  string containing the code to check

Return:
  dictionary with the keys 'error' and 'warnings' which hold a list containing details about the error/ warnings (file name, line number, column, codestring (only at syntax errors), the message, a list with arguments for the message)

Return Type:
  dict

Up

## initBatchService

initBatchService()

Initialize the batch service and return the entry point.

Return:
  the entry point for the background client

Return Type:
  func

Up

## initService

initService()

Initialize the service and return the entry point.

Return:
  the entry point for the background client

Return Type:
  func

Up

## tomlSyntaxBatchCheck

tomlSyntaxBatchCheck(argumentsList, send, fx, cancelled, maxProcesses=0)

Module function to check syntax for a batch of files.

argumentsList (list)
  list of arguments tuples as given for tomlSyntaxCheck
send (func)
  reference to send function
fx (str)
  registered service name
cancelled (func)
  reference to function checking for a cancellation
maxProcesses (int)
  number of processes to be used

Up

## tomlSyntaxCheck

tomlSyntaxCheck(file, codestring)

Function to check a TOML source file for syntax errors.

file (str)
  source filename
codestring (str)
  string containing the code to check

Return:
  dictionary with the keys 'error' and 'warnings' which hold a list containing details about the error/ warnings (file name, line number, column, codestring (only at syntax errors), the message, a list with arguments for the message)

Return Type:
  dict

Up

## workerTask

workerTask(inputQueue, outputQueue)

Module function acting as the parallel worker for the syntax check.

inputQueue (multiprocessing.Queue)
  input queue
outputQueue (multiprocessing.Queue)
  output queue

Up